@@ -20,6 +20,8 @@
 #include "ExcludeRules.h"
 #include "PkgReader.h"
 #include "MountPoints.h"
+#include "FormatUtil.h"
+#include "Logger.h"
 #include "Exception.h"
 
 #define VERBOSE_EXCLUDE_RULES	1
