@@ -17,7 +17,7 @@ class QAction;
 
 namespace QDirStat
 {
-    class PercentBarDelegate;
+    class DirTreePercentBarDelegate;
     class SizeColDelegate;
     class HeaderTweaker;
     class SelectionModelProxy;
@@ -128,12 +128,31 @@ namespace QDirStat
 	virtual void currentChanged( const QModelIndex & current,
 				     const QModelIndex & oldCurrent ) Q_DECL_OVERRIDE;
 
+        /**
+         * Keyboard event handler.
+         *
+         * Reimplemented from QTreeView.
+         **/
+        virtual void keyPressEvent( QKeyEvent * event ) Q_DECL_OVERRIDE;
+
+        /**
+         * Mouse button handler.
+         *
+         * Don't let QTreeView steal and misappropriate the mouse back /
+         * forward buttons; we want consistent history buttons throughout the
+         * application.
+         *
+         * Reimplemented from QTreeView.
+         **/
+        virtual void mousePressEvent( QMouseEvent * event ) Q_DECL_OVERRIDE;
+
+
 	// Data members
 
-	PercentBarDelegate * _percentBarDelegate;
-        SizeColDelegate    * _sizeColDelegate;
-	HeaderTweaker	   * _headerTweaker;
-	CleanupCollection  * _cleanupCollection;
+	DirTreePercentBarDelegate * _percentBarDelegate;
+        SizeColDelegate *           _sizeColDelegate;
+	HeaderTweaker *             _headerTweaker;
+	CleanupCollection *         _cleanupCollection;
 
     };	// class DirTreeView
 
