@@ -11,6 +11,7 @@
 #include <sys/stat.h>
 #include <pwd.h>	// getpwuid()
 #include <grp.h>	// getgrgid()
+#include <time.h>       // gmtime()
 #include <unistd.h>
 
 #include <QDateTime>
@@ -21,6 +22,7 @@
 #include "Attic.h"
 #include "DirTree.h"
 #include "PkgInfo.h"
+#include "FormatUtil.h"
 #include "SysUtil.h"
 #include "Logger.h"
 #include "Exception.h"
@@ -57,6 +59,8 @@ FileInfo::FileInfo( DirTree    * tree,
     _size	   = 0;
     _blocks	   = 0;
     _mtime	   = 0;
+    _mtimeYear     = -1;
+    _mtimeMonth    = -1;
     _allocatedSize = 0;
     _magic	   = FileInfoMagic;
 }
@@ -82,6 +86,8 @@ FileInfo::FileInfo( const QString & filenameWithoutPath,
     _uid	   = statInfo->st_uid;
     _gid	   = statInfo->st_gid;
     _mtime	   = statInfo->st_mtime;
+    _mtimeYear     = -1;
+    _mtimeMonth    = -1;
     _magic	   = FileInfoMagic;
     _allocatedSize = 0;
 
@@ -118,14 +124,16 @@ FileInfo::FileInfo( const QString & filenameWithoutPath,
 	    && _blocks >= 0
 	    && _allocatedSize + FRAGMENT_SIZE < _size; // allow for intelligent fragment handling
 
+#if 0
 	if ( _isSparseFile )
 	{
 	    logDebug() << "Found sparse file: " << this
-		       << "    Byte size: " << formatSize( _size )
-		       << "  Allocated: " << formatSize( _allocatedSize )
+		       << "    Byte size: "     << formatSize( _size )
+		       << "  Allocated: "       << formatSize( _allocatedSize )
 		       << " (" << (int) _blocks << " blocks)"
 		       << endl;
 	}
+#endif
 
 #if 0
 	if ( isFile() && _links > 1 )
@@ -157,6 +165,8 @@ FileInfo::FileInfo( DirTree *	    tree,
     _mode	   = mode;
     _size	   = size;
     _mtime	   = mtime;
+    _mtimeYear     = -1;
+    _mtimeMonth    = -1;
     _allocatedSize = 0;
     _links	   = links;
     _uid	   = 0;
@@ -294,21 +304,26 @@ QString FileInfo::debugUrl() const
     if ( _tree && this == _tree->root() )
 	return "<root>";
 
-    if ( isDotEntry() )
-	return url() + "/" + dotEntryName();
+    QString result = url();
 
-    if ( isAttic() )
+    if ( isDotEntry() )
+    {
+	result += "/" + dotEntryName();
+    }
+    else if ( isAttic() )
     {
 	if ( _parent )
 	{
 	    if ( _tree && _parent != _tree->root() )
-		return _parent->debugUrl() + "/" + atticName();
+		result = _parent->debugUrl() + "/" + atticName();
 	}
-
-	return url() + "/" + atticName();
+        else
+            result += "/" + atticName();
     }
 
-    return url() ;
+    result.replace( "//", "/" );
+
+    return result;
 }
 
 
@@ -565,83 +580,6 @@ void FileInfo::setIgnoreHardLinks( bool ignore )
 }
 
 
-//---------------------------------------------------------------------------
-
-
-QString QDirStat::formatSize( FileSize lSize )
-{
-    return formatSize( lSize, 1 );
-}
-
-
-QString QDirStat::formatSize( FileSize lSize, int precision )
-{
-    QString sizeString;
-    int	    unitIndex = 0;
-
-    static QStringList units;
-
-    if ( units.isEmpty() )
-    {
-	units << QObject::tr( "Bytes" )
-	      << QObject::tr( "kB" )
-	      << QObject::tr( "MB" )
-	      << QObject::tr( "GB" )
-	      << QObject::tr( "TB" )
-	      << QObject::tr( "PB" )
-	      << QObject::tr( "EB" )
-	      << QObject::tr( "ZB" )
-	      << QObject::tr( "YB" );
-    }
-
-    if ( lSize < 1024 )
-    {
-	sizeString.setNum( lSize );
-	sizeString += " " + units.at( unitIndex );
-    }
-    else
-    {
-	double size = lSize;
-
-	while ( size >= 1024.0 && unitIndex < units.size() - 1 )
-	{
-	    size /= 1024.0;
-	    ++unitIndex;
-	}
-
-	sizeString.setNum( size, 'f', precision );
-	sizeString += " " + units.at( unitIndex );
-    }
-
-    return sizeString;
-}
-
-
-QString QDirStat::formatByteSize( FileSize size )
-{
-
-    QString bytesString;
-    bytesString.setNum( size );
-
-    QString sizeString;
-
-    while ( ! bytesString.isEmpty() )
-    {
-	QString digits = bytesString.right( 3 );
-	bytesString.chop( 3 );
-
-	if ( ! sizeString.isEmpty() )
-	    sizeString.prepend( " " ); // thousands separator
-
-	sizeString.prepend( digits );
-    }
-
-    sizeString = QObject::tr( "%1 Bytes" ).arg( sizeString );
-
-    return sizeString;
-}
-
-
 DirInfo * FileInfo::toDirInfo()
 {
     DirInfo * dirInfo = dynamic_cast<DirInfo *>( this );
@@ -731,19 +669,42 @@ QString FileInfo::symLinkTarget()
 }
 
 
-
-
-
-QString QDirStat::formatTime( time_t rawTime )
+short FileInfo::mtimeYear()
 {
-    if ( rawTime == (time_t) 0 )
-	return "";
+    if ( _mtimeYear == -1 )
+        processMtime();
 
-    QDateTime time = QDateTime::fromTime_t( rawTime );
-    return time.toString( Qt::DefaultLocaleShortDate );
+    return _mtimeYear;
 }
 
 
+short FileInfo::mtimeMonth()
+{
+    if ( _mtimeMonth == -1 )
+        processMtime();
+
+    return _mtimeMonth;
+}
+
+
+void  FileInfo::processMtime()
+{
+    if ( isPseudoDir() || isPkgInfo() )
+        return;
+
+    // Using gmtime() which is standard C/C++
+    // unlike gmtime_r() which is not
+    struct tm * mtime_tm = gmtime( &_mtime );
+
+    _mtimeYear  = mtime_tm->tm_year + 1900;
+    _mtimeMonth = mtime_tm->tm_mon  + 1;
+}
+
+
+
+//---------------------------------------------------------------------------
+
+
 // See also FileInfo::baseName()
 
 QString QDirStat::baseName( const QString & fileName )
@@ -752,74 +713,3 @@ QString QDirStat::baseName( const QString & fileName )
     return segments.isEmpty() ? "" : segments.last();
 }
 
-
-QString QDirStat::formatPermissions( mode_t mode )
-{
-    return symbolicMode( mode, true ) + "  " + formatOctal( ALLPERMS & mode );
-}
-
-
-QString QDirStat::formatOctal( int number )
-{
-    return QString( "0" ) + QString::number( number, 8 );
-}
-
-
-QString QDirStat::symbolicMode( mode_t mode, bool omitTypeForRegularFiles )
-{
-    QString result;
-
-    // Type
-
-    if	    ( S_ISDIR ( mode ) )	  result = "d";
-    else if ( S_ISCHR ( mode ) )	  result = "c";
-    else if ( S_ISBLK ( mode ) )	  result = "b";
-    else if ( S_ISFIFO( mode ) )	  result = "p";
-    else if ( S_ISLNK ( mode ) )	  result = "l";
-    else if ( S_ISSOCK( mode ) )	  result = "s";
-    else if ( ! omitTypeForRegularFiles ) result = "-";
-
-    // User
-
-    result += ( mode & S_IRUSR ) ? "r" : "-";
-    result += ( mode & S_IWUSR ) ? "w" : "-";
-
-    if ( mode & S_ISUID )
-	result += "s";
-    else
-	result += ( mode & S_IXUSR ) ? "x" : "-";
-
-    // Group
-
-    result += ( mode & S_IRGRP ) ? "r" : "-";
-    result += ( mode & S_IWGRP ) ? "w" : "-";
-
-    if ( mode & S_ISGID )
-	result += "s";
-    else
-	result += ( mode & S_IXGRP ) ? "x" : "-";
-
-    // Other
-
-    result += ( mode & S_IROTH ) ? "r" : "-";
-    result += ( mode & S_IWOTH ) ? "w" : "-";
-
-    if ( mode & S_ISVTX )
-	result += "t";
-    else
-	result += ( mode & S_IXOTH ) ? "x" : "-";
-
-    return result;
-}
-
-
-QString QDirStat::formatFilesystemObjectType( mode_t mode )
-{
-    if	    ( S_ISDIR ( mode ) ) return QObject::tr( "Directory"	);
-    else if ( S_ISCHR ( mode ) ) return QObject::tr( "Character Device" );
-    else if ( S_ISBLK ( mode ) ) return QObject::tr( "Block Device"	);
-    else if ( S_ISFIFO( mode ) ) return QObject::tr( "Named Pipe"	);
-    else if ( S_ISLNK ( mode ) ) return QObject::tr( "Symbolic Link"	);
-    else if ( S_ISSOCK( mode ) ) return QObject::tr( "Socket"		);
-    else			 return QObject::tr( "File"		);
-}
