@@ -18,6 +18,7 @@
 #include <QTextStream>
 #include <QList>
 
+#include "FileSize.h"
 #include "Logger.h"
 
 // The size of a standard disk block.
@@ -31,11 +32,6 @@
 
 namespace QDirStat
 {
-    typedef long long FileSize;
-
-#define FileSizeMax   LLONG_MAX
-// 0x7FFFFFFFFFFFFFFFLL == 9223372036854775807LL
-
 #define FileInfoMagic 4242
 
     // Forward declarations
@@ -324,6 +320,24 @@ namespace QDirStat
 	 **/
 	time_t mtime() const { return _mtime; }
 
+        /**
+         * The year of the modification time of the file (1970-2037).
+         *
+         * The first call to this will calculate the value from _mtime and
+         * cache it (and the corresponding month); that's why this is not a
+         * const method.
+         **/
+        short mtimeYear();
+
+        /**
+         * The month of the modification time of the file (1-12).
+         *
+         * The first call to this will calculate the value from _mtime and
+         * cache it (and the corresponding year); that's why this is not a
+         * const method.
+         **/
+        short mtimeMonth();
+
 	/**
 	 * Returns the total size in bytes of this subtree.
 	 * Derived classes that have children should overwrite this.
@@ -904,6 +918,13 @@ namespace QDirStat
 
     protected:
 
+        /**
+         * Calculate values that are dependent on _mtime, yet quite expensive
+         * to calculate, and cache them: _mtimeYear, _mtimeMonth
+         **/
+        void processMtime();
+
+
 	// Data members.
 	//
 	// Keep this short in order to use as little memory as possible -
@@ -921,8 +942,10 @@ namespace QDirStat
 	gid_t		_gid;			// Group ID of owner
 	FileSize	_size;			// size in bytes
 	FileSize	_blocks;		// 512 bytes blocks
-	time_t		_mtime;			// modification time
 	FileSize	_allocatedSize;		// allocated size in bytes
+	time_t		_mtime;			// modification time
+        short           _mtimeYear;             // year  of the modification time or -1
+        short           _mtimeMonth;            // month of the modification time or -1
 
 	DirInfo	 *	_parent;		// pointer to the parent entry
 	FileInfo *	_next;			// pointer to the next entry
@@ -942,40 +965,7 @@ namespace QDirStat
     //			       Static Functions
     //----------------------------------------------------------------------
 
-
-    /**
-     * Format a file / subtree size human readable, i.e. in "GB" / "MB"
-     * etc. rather than huge numbers of digits. 'precision' is the number of
-     * digits after the decimal point.
-     *
-     * Note: For logDebug() etc., operator<< is overwritten to do exactly that:
-     *
-     *	   logDebug() << "Size: " << x->totalSize() << endl;
-     **/
-    QString formatSize( FileSize size );
-
-    // Can't use a default argument when using this as a function pointer,
-    // so we really need the above overloaded version.
-    QString formatSize( FileSize size, int precision );
-
-    /**
-     * Format a file / subtree size as bytes, but still human readable with a
-     * space as a thousands separator, i.e. "12 345 678 Bytes".
-     *
-     * Intentionally NOT using the locale's thousands separator since this
-     * causes confusion to no end when it's only one of them, and it's unclear
-     * what locale is used: German uses "," as the decimal separator and "." as
-     * the thousands separator, exactly the other way round as English. So it's
-     * never clear if 12.345 is a little more than twelve or twelve thousand.
-     * A space character avoids this confusion.
-     **/
-    QString formatByteSize( FileSize size );
-
-    /**
-     * Format a timestamp (like the latestMTime()) human-readable.
-     **/
-    QString formatTime( time_t rawTime );
-
+    
     /**
      * Return the last pathname component of a file name.
      *
@@ -990,34 +980,6 @@ namespace QDirStat
      **/
     QString baseName( const QString & fileName );
 
-    /**
-     * Format the mode (the permissions bits) returned from the stat() system
-     * call in the commonly used formats, both symbolic and octal, e.g.
-     *	   drwxr-xr-x  0755
-     **/
-    QString formatPermissions( mode_t mode );
-
-    /**
-     * Format a number in octal with a leading zero.
-     **/
-    QString formatOctal( int number );
-
-    /**
-     * Return the mode (the permission bits) returned from stat() like the
-     * "ls -l" shell command does, e.g.
-     *
-     *	   drwxr-xr-x
-     *
-     * 'omitTypeForRegularFiles' specifies if the leading "-" should be omitted.
-     **/
-    QString symbolicMode( mode_t perm, bool omitTypeForRegularFiles = false );
-
-    /**
-     * Format the filesystem object type from a mode, e.g. "Directory",
-     * "Symbolic Link", "Block Device", "File".
-     **/
-    QString formatFilesystemObjectType( mode_t mode );
-
 
     /**
      * Print the debugUrl() of a FileInfo in a debug stream.
@@ -1037,17 +999,6 @@ namespace QDirStat
 	return stream;
     }
 
-
-    /**
-     * Human-readable output of a file size in a debug stream.
-     **/
-    inline QTextStream & operator<< ( QTextStream & stream, FileSize lSize )
-    {
-	stream << formatSize( lSize );
-
-	return stream;
-    }
-
 }	// namespace QDirStat
 
 
