@@ -17,8 +17,6 @@
 
 namespace QDirStat
 {
-    class DirTree;
-
     /**
      * Helper class for extended file mtime statistics.
      * This is very similar to FileSizeStats.
@@ -37,24 +35,10 @@ namespace QDirStat
     public:
 
 	/**
-	 * Constructor.
+	 * Constructor. If 'subtree' is non-null, immediately collect data from
+	 * that subtree.
 	 **/
-	FileMTimeStats();
-
-        /**
-         * Populate the internal 'data' list.
-         *
-         * Implemented from PercentileStats.
-         * This overloaded version does not do anything.
-         **/
-        virtual void collect() Q_DECL_OVERRIDE;
-
-	/**
-	 * Recurse through all file elements in the tree and append the mtime
-	 * for each file to the data collection. Notice that the data are
-	 * unsorted after this.
-	 **/
-	void collect( DirTree * tree );
+	FileMTimeStats( FileInfo * subtree = 0 );
 
 	/**
 	 * Recurse through all file elements in the subtree and append the
