@@ -12,7 +12,7 @@
 
 #include "FileSizeStats.h"
 #include "FileInfoIterator.h"
-#include "DirTree.h"
+#include "FormatUtil.h"
 #include "Exception.h"
 
 #define VERBOSE_SORT_THRESHOLD  50000
@@ -20,23 +20,14 @@
 using namespace QDirStat;
 
 
-FileSizeStats::FileSizeStats():
+FileSizeStats::FileSizeStats( FileInfo * subtree ):
     PercentileStats()
 {
-
-}
-
-
-void FileSizeStats::collect()
-{
-
-}
-
-void FileSizeStats::collect( DirTree * tree )
-{
-    Q_CHECK_PTR( tree );
-
-    collect( tree->root() );
+    if ( subtree )
+    {
+        collect( subtree );
+        sort();
+    }
 }
 
 
@@ -71,20 +62,6 @@ void FileSizeStats::collect( FileInfo * subtree )
 }
 
 
-void FileSizeStats::collect( DirTree * tree, const QString & suffix )
-{
-    Q_CHECK_PTR( tree );
-
-    if ( ! suffix.startsWith( "." ) )
-    {
-        logError() << "Suffix should start with \".\" - got \""
-                   << suffix << "\"" << endl;
-    }
-
-    collect( tree->root(), suffix );
-}
-
-
 void FileSizeStats::collect( FileInfo * subtree, const QString & suffix )
 {
     Q_CHECK_PTR( subtree );
