@@ -41,10 +41,12 @@ namespace QDirStat
 
 	/**
 	 * Open an "open package" dialog and wait for the user to enter
-	 * values. 'canceled_ret' is a return parameter that is set to 'true'
-	 * if the user canceled the dialog.
+	 * values.
+         *
+         * 'canceled_ret' is a return parameter that (if non-null) is set to
+	 * 'true' if the user canceled the dialog.
 	 **/
-	static PkgFilter askPkgFilter( bool &	 canceled_ret,
+	static PkgFilter askPkgFilter( bool    * canceled_ret,
 				       QWidget * parent = 0   );
 
 	/**
